@@ -112,8 +112,6 @@ static void store_monitor_cb (GFileMonitor *, GFile *, GFile *,
                               GFileMonitorEvent, gpointer);
 static void weak_destroy_cb  (gpointer, GObject *);
 
-static gint recent_item_mru_comp_func (gconstpointer a, gconstpointer b);
-
 static gchar *find_package_data_file (const gchar *filename);
 
 static gint BookmarkAgent_private_offset;
@@ -148,22 +146,6 @@ bookmark_agent_get_type ()
 	return g_define_type_id;
 }
 
-BookmarkAgent *
-bookmark_agent_get_instance (BookmarkStoreType type)
-{
-	g_return_val_if_fail (0 <= type, NULL);
-	g_return_val_if_fail (type < BOOKMARK_STORE_N_TYPES, NULL);
-
-	if (! instances [type]) {
-		instances [type] = bookmark_agent_new (type);
-		g_object_weak_ref (G_OBJECT (instances [type]), weak_destroy_cb, GINT_TO_POINTER (type));
-	}
-	else
-		g_object_ref (G_OBJECT (instances [type]));
-
-	return instances [type];
-}
-
 gboolean
 bookmark_agent_has_item (BookmarkAgent *this, const gchar *uri)
 {
@@ -186,7 +168,11 @@ bookmark_agent_add_item (BookmarkAgent *this, const BookmarkItem *item)
 	g_bookmark_file_set_mime_type (priv->store, item->uri, item->mime_type);
 
 	if (item->mtime)
+		#if GLIB_CHECK_VERSION(2,66,0)
+		g_bookmark_file_set_modified_date_time (priv->store, item->uri, item->mtime);
+		#else
 		g_bookmark_file_set_modified (priv->store, item->uri, item->mtime);
+		#endif
 
 	if (item->title)
 		g_bookmark_file_set_title (priv->store, item->uri, item->title);
@@ -208,13 +194,12 @@ bookmark_agent_move_item (BookmarkAgent *this, const gchar *uri, const gchar *ur
 	if (! TYPE_IS_RECENT (priv->type))
 		return;
 
-	gtk_recent_manager_move_item (
-		gtk_recent_manager_get_default (), uri, uri_new, & error);
-
-	if (error)
-		libslab_handle_g_error (
-			& error, "%s: unable to update %s with renamed file, [%s] -> [%s].",
-			G_STRFUNC, priv->store_path, uri, uri_new);
+	gtk_recent_manager_move_item (gtk_recent_manager_get_default (), uri, uri_new, &error);
+	if (error) {
+		g_warning ("Unable to update %s with renamed file, [%s] -> [%s]: %s",
+		           priv->store_path, uri, uri_new, error->message);
+		g_error_free (error);
+	}
 }
 
 void
@@ -232,12 +217,12 @@ bookmark_agent_purge_items (BookmarkAgent *this)
 	uris = g_bookmark_file_get_uris (priv->store, &uris_len);
 	if (TYPE_IS_RECENT (priv->type)) {
 		for (i = 0; i < uris_len; i++) {
-			gtk_recent_manager_remove_item (gtk_recent_manager_get_default (), uris [i], & error);
-
-			if (error)
-				libslab_handle_g_error (
-					& error, "%s: unable to remove [%s] from %s.",
-					G_STRFUNC, priv->store_path, uris [i]);
+			gtk_recent_manager_remove_item (gtk_recent_manager_get_default (), uris [i], &error);
+			if (error) {
+				g_warning ("Unable to remove [%s] from %s: %s",
+				           priv->store_path, uris [i], error->message);
+				g_error_free (error);
+			}
 		}
 	} else {
 		for (i = 0; i < uris_len; i++) {
@@ -267,13 +252,11 @@ bookmark_agent_remove_item (BookmarkAgent *this, const gchar *uri)
 		return;
 
 	if (TYPE_IS_RECENT (priv->type)) {
-		gtk_recent_manager_remove_item (
-			gtk_recent_manager_get_default (), uri, & error);
-
-		if (error)
-			libslab_handle_g_error (
-				& error, "%s: unable to remove [%s] from %s.",
-				G_STRFUNC, priv->store_path, uri);
+		gtk_recent_manager_remove_item (gtk_recent_manager_get_default (), uri, &error);
+		if (error) {
+			g_warning ("Unable to remove [%s] from %s: %s", priv->store_path, uri, error->message);
+			g_error_free (error);
+		}
 	}
 	else {
 		rank = get_rank (this, uri);
@@ -342,13 +325,17 @@ make_items_from_bookmark_file (BookmarkAgent *this, GBookmarkFile *store)
 
 			item->uri       = g_strdup (uris [i]);
 			item->mime_type = g_bookmark_file_get_mime_type (store, uris [i], NULL);
-			item->mtime     = g_bookmark_file_get_modified  (store, uris [i], NULL);
+			#if GLIB_CHECK_VERSION(2,66,0)
+			item->mtime     = g_bookmark_file_get_modified_date_time  (store, uris [i], NULL);
+			#else
+			item->mtime     = g_bookmark_file_get_modified (store, uris [i], NULL);
+			#endif
 
 			items_ordered = g_list_prepend (items_ordered, item);
 		}
 	}
 
-	items_ordered = g_list_sort (items_ordered, recent_item_mru_comp_func);
+	items_ordered = g_list_sort (items_ordered, g_date_time_compare);
 
 	g_strfreev (uris);
 
@@ -377,7 +364,11 @@ bookmark_agent_update_from_bookmark_file (BookmarkAgent *this, GBookmarkFile *st
 		item = (BookmarkItem *) node->data;
 
 		g_bookmark_file_set_mime_type (priv->store, item->uri, item->mime_type);
-		g_bookmark_file_set_modified  (priv->store, item->uri, item->mtime);
+		#if GLIB_CHECK_VERSION(2,66,0)
+		g_bookmark_file_set_modified_date_time  (priv->store, item->uri, item->mtime);
+		#else
+		g_bookmark_file_set_modified (priv->store, item->uri, item->mtime);
+		#endif
 
 		bookmark_item_free (item);
 	}
@@ -565,6 +556,22 @@ bookmark_agent_new (BookmarkStoreType type)
 	return this;
 }
 
+BookmarkAgent *
+bookmark_agent_get_instance (BookmarkStoreType type)
+{
+	g_return_val_if_fail (0 <= type, NULL);
+	g_return_val_if_fail (type < BOOKMARK_STORE_N_TYPES, NULL);
+
+	if (! instances [type]) {
+		instances [type] = bookmark_agent_new (type);
+		g_object_weak_ref (G_OBJECT (instances [type]), weak_destroy_cb, GINT_TO_POINTER (type));
+	}
+	else
+		g_object_ref (G_OBJECT (instances [type]));
+
+	return instances [type];
+}
+
 static void
 get_property (GObject *g_obj, guint prop_id, GValue *value, GParamSpec *pspec)
 {
@@ -723,7 +730,11 @@ update_items (BookmarkAgent *this)
 			priv->items [i]->uri       = g_strdup (uris_ordered [i]);
 			priv->items [i]->title     = g_bookmark_file_get_title     (priv->store, uris_ordered [i], NULL);
 			priv->items [i]->mime_type = g_bookmark_file_get_mime_type (priv->store, uris_ordered [i], NULL);
-			priv->items [i]->mtime     = g_bookmark_file_get_modified  (priv->store, uris_ordered [i], NULL);
+			#if GLIB_CHECK_VERSION(2,66,0)
+			priv->items [i]->mtime     = g_bookmark_file_get_modified_date_time (priv->store, uris_ordered [i], NULL);
+			#else
+			priv->items [i]->mtime     = g_bookmark_file_get_modified (priv->store, uris_ordered [i], NULL);
+			#endif
 			priv->items [i]->app_name  = NULL;
 			priv->items [i]->app_exec  = NULL;
 
@@ -847,10 +858,12 @@ load_xbel_store (BookmarkAgent *this)
 		g_bookmark_file_free (priv->store);
 		priv->store = g_bookmark_file_new ();
 
-		libslab_handle_g_error (
-			& error, "%s: couldn't load bookmark file [%s]\n",
-			G_STRFUNC, priv->store_path ? priv->store_path : "NULL");
-
+		if (error) {
+			g_debug ("Couldn't load bookmark file [%s]: %s", priv->store_path, error->message);
+			g_error_free (error);
+		} else {
+			g_debug ("Couldn't load bookmark file [NULL]");
+		}
 		return;
 	}
 
@@ -998,7 +1011,7 @@ update_user_spec_path (BookmarkAgent *this)
 		}
 	}
 
-	if (libslab_strcmp (priv->store_path, path)) {
+	if (g_strcmp0 (priv->store_path, path)) {
 		g_free (priv->store_path);
 		priv->store_path = path;
 
@@ -1032,10 +1045,15 @@ save_xbel_store (BookmarkAgent *this)
 
 	GError *error = NULL;
 
+	if (g_bookmark_file_to_file (priv->store, priv->store_path, &error))
+		return;
 
-	if (! g_bookmark_file_to_file (priv->store, priv->store_path, & error))
-		libslab_handle_g_error (
-			& error, "%s: couldn't save bookmark file [%s]\n", G_STRFUNC, priv->store_path);
+	if (error) {
+		g_warning ("Couldn't save bookmark file [%s]: %s", priv->store_path, error->message);
+		g_error_free (error);
+	} else {
+		g_warning ("Couldn't save bookmark file [%s]", priv->store_path);
+	}
 }
 
 static void
@@ -1056,7 +1074,7 @@ create_app_item (BookmarkAgent *this, const gchar *uri)
 	if (! uri_new)
 		return;
 
-	if (libslab_strcmp (uri, uri_new))
+	if (g_strcmp0 (uri, uri_new))
 		g_bookmark_file_move_item (priv->store, uri, uri_new, NULL);
 
 	g_free (uri_new);
@@ -1115,7 +1133,7 @@ create_doc_item (BookmarkAgent *this, const gchar *uri)
 	if (!uri_new)
 		return;
 
-	if (libslab_strcmp (uri, uri_new))
+	if (g_strcmp0 (uri, uri_new))
 		g_bookmark_file_move_item (priv->store, uri, uri_new, NULL);
 
 	g_free (uri_new);
@@ -1199,7 +1217,7 @@ create_dir_item (BookmarkAgent *this, const gchar *uri)
 	if (name)
 		g_bookmark_file_set_title (priv->store, uri, name);
 
-	if (uri_new && libslab_strcmp (uri, uri_new))
+	if (uri_new && g_strcmp0 (uri, uri_new))
 		g_bookmark_file_move_item (priv->store, uri, uri_new, NULL);
 
 	if (gotta_free_name) {
@@ -1222,9 +1240,3 @@ weak_destroy_cb (gpointer data, GObject *g_obj)
 {
 	instances [GPOINTER_TO_INT (data)] = NULL;
 }
-
-static gint
-recent_item_mru_comp_func (gconstpointer a, gconstpointer b)
-{
-	return ((BookmarkItem *) b)->mtime - ((BookmarkItem *) a)->mtime;
-}
